import { ILiteralsLoader } from 'base-foundation';
import { Observable } from 'rxjs';
import { ILiterals } from 'base-foundation';
import { HttpClient } from '@angular/common/http';
import { IWebI18nOptions } from './web-i18n-options.interface';
import { ThfI18nService } from '@totvs/thf-ui/services/thf-i18n';
/**
 * Serviço que realiza o carregamento das literais do serviço de internacionalização
 * @implements {ILiteralsLoader}
 */
export declare class IntlLiteralsLoaderService implements ILiteralsLoader {
    private http;
    private thfI18nService;
    /**
     * Atributo com opções de internacionalização Web
     */
    private webOptions;
    /**
     * Representa o cache da informação, em memória
     */
    private cache;
    /**
     * Método construtor da classe
     * @param http Parâmetro do serviço de Http
     * @param thfI18nService Parâmetro do serviço de internacionalização do THF
     */
    constructor(http: HttpClient, thfI18nService: ThfI18nService);
    /**
     * Método responsável por alterar as opções para carregamento de literais
     * @param options Parâmetro com as opções de internacionalização (url, language, context)
     */
    updateOptions(options: IWebI18nOptions): Observable<ILiterals>;
    /**
     * Método responsável por realizar o carregamento inicial das literais
     */
    load(): Observable<ILiterals>;
    /**
     * Detecta se ocorreram mudanças na configuração
     */
    private optionsWasChanged;
    /**
     * Método responsável por carregar as literais do contexto do THF
     */
    private updateLiteralsFromThfContext;
}
